/*
* Copyright 2012-2016 Broad Institute, Inc.
* 
* Permission is hereby granted, free of charge, to any person
* obtaining a copy of this software and associated documentation
* files (the "Software"), to deal in the Software without
* restriction, including without limitation the rights to use,
* copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the
* Software is furnished to do so, subject to the following
* conditions:
* 
* The above copyright notice and this permission notice shall be
* included in all copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
* OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
* HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
* FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
* THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

package org.broadinstitute.gatk.queue.qscripts.examples

import org.broadinstitute.gatk.queue.QScript
import org.broadinstitute.gatk.queue.extensions.gatk._

/**
 * Script used for testing output to /dev/null, deleting .bai files, etc.
 */
class ExamplePrintReads extends QScript {
  @Input(doc="The reference file for the bam files.", shortName="R")
  var referenceFile: File = _

  @Input(doc="Bam file to genotype.", shortName="I")
  var bamFile: File = _

  @Output(doc="Bam output", shortName="out")
  var outFile: File = _

  @Argument(doc="One or more genomic intervals over which to operate", shortName="L", required=false)
  var intervals: Seq[String] = Nil

  @Argument(doc = "Don't output a program tag", shortName = "npt", required = false)
  var noPGTag: Boolean = _

  def script() {
    val printReads = new PrintReads
    printReads.reference_sequence = referenceFile
    printReads.memoryLimit = 2
    printReads.scatterCount = 3
    printReads.input_file :+= bamFile
    printReads.out = outFile
    printReads.intervalsString = intervals
    printReads.no_pg_tag = noPGTag
    add(printReads)
  }
}
